@@ -16,14 +16,15 @@ ok(1); # If we made it this far, we're ok.
 print <<ENDE;
 
 You will need the winamp-plugin "httpQ" (Written by Kosta Arvanitis) installed on the machine playing
-the music via winamp/shoutcast. You may find it at:
-
-	http://www.kostaa.com/winamp/
-
-or otherwise search the plugin-section at
+the music via winamp/shoutcast. You may find it via searching at the winamp headquarter:
 
 	http://www.winamp.com
 
+Or directly from the author (for the recent version):
+
+	http://www.csc.uvic.ca/~karvanit/
+	http://www.csc.uvic.ca/~karvanit/downloads/httpq19.exe
+
 After installation you have to activate httpQ through the winamp preferences dialog. In the
 "Plug-ins/General Purpose" section, select httpQ and press the configure button at the bottom.
 
@@ -31,13 +32,13 @@ Install and run it before the this test, otherwise it will fail (not important).
 
 ENDE
 
-		print 'Enter the host:port:password where winamp is installed and httpQ is running [localhost:4800]: ';
+		print 'Enter the host:port where winamp is installed and httpQ is running [localhost:4800]: ';
 
 		chomp( my $input = <STDIN> );
 
-		my ( $host, $port, $passwd ) = split ':', $input;
+		my ( $host, $port ) = split ':', $input;
 
-		my $winamp = Winamp::Control->new( host => $host || '127.0.0.1', port => $port || 4800, passwd => $passwd );
+		my $winamp = Winamp::Control->new( host => $host || '127.0.0.1', port => $port || 4800 );
 
 		if( my $ver = $winamp->getversion )
 		{
@@ -52,13 +53,11 @@ ENDE
 
 print <<ENDE;
 
-TEST FAILED !
+TEST FAILED:
 
-You should verify:
-
-	1) Winamp was started.
-	2) The httpQ-plugin was started (explicitly started httpQ with the 'start'-button or automatic).
-	3) You have entered the correct host and port.
+	1) If winamp was started.
+	2) If the httpQ-plugin was started (explicitly started httpQ with the 'start'-button).
+	3) If you have entered the correct host and port.
 
 ENDE
 		}
